==> cbsd-10.0.5.txz: usr/local/cbsd/cbsd.lua <==
product="cbsd"
myversion="10.0.5"

if not workdir then
    print ( "no workdir" )
    os.exit(0)
end

distdir="/usr/local/cbsd"
subr= workdir .. "/nc.subr"
nodenamefile= workdir .. "/nodename"
settingstui= workdir .. "/settings-tui.subr"
dialog= workdir .. "/dialog.subr"
tools= workdir .. "/tools.subr"
mdtools= workdir .. "/mdtools.subr"
zfstool= workdir .. "/zfs.subr"
jfs= workdir .. "/jfs.subr"
color= workdir .. "/ansiicolor.subr"
nodes= workdir .. "/nodes.subr"
jrcconf= workdir .. "/rcconf.subr"
vimageconf= workdir .. "/vnet.subr"
inventory= workdir .. "/nc.inventory"
nodedescr= workdir .. "/node.desc"
initenv= workdir .. "/initenv.subr"
system= workdir .. "/system.subr"
buildconf= workdir .. "/build.subr"
distccacheconf= workdir .. "/distccache.subr"
base2pkgconf= workdir .. "/base2pkg.subr"
mailconf= workdir .. "/mailtools.subr"
strings= workdir .. "/strings.subr"
miscdir= workdir .. "/misc"
jobdir= workdir .. "/job"
spooldir= workdir .. "/spool"
taskdir= spooldir .. "/task"
srcdir= workdir .. "/src"
tmpdir= workdir .. "/tmp"
ftmpdir= workdir .. "/ftmp"
importdir= workdir .. "/import"
exportdir= workdir .. "/export"
basejaildir= workdir .. "/basejail"
basejailpref="base"
jaildatadir= workdir .. "/jails-data"
jailfstabdir= workdir .. "/jails-fstab"
jailrcconfdir= workdir .. "/jails-rcconf"
jailfstabpref="fstab."
jaildir= workdir .. "/jails"
jaildatapref="data"
jailsysdir= workdir .. "/jails-system"
bindir= workdir .. "/bin"
etcdir= workdir .. "/etc"
jailctldir= workdir .. "/jailctl"
nodectl= workdir .. "/nodectl"
rcddir= workdir .. "/rc.d"
sbindir= workdir .. "/sbin"
systemdir= workdir .. "/system"
moduledir= workdir .. "/modules"
toolsdir= workdir .. "/tools"
upgradedir= workdir .. "/upgrade"
vardir= workdir .. "/var"
rundir= vardir .. "/run"
crondir= vardir .. "/cron"
maildir= vardir .. "/mail"
crontabsdir= crondir .. "/tabs"
logdir= vardir .. "/log"
sharedir= workdir .. "/share"
dbdir= vardir .. "/db"
localcbsdconffile="cbsd.conf"
localcbsdconf= workdir .. localcbsdconffile
sudoexecdir= workdir .. "/sudoexec"
systemsudoexecdir= distdir .. "/sudoexec"
cbsduser="cbsd"
production="0"
rsshdir= workdir .. "/.rssh"
sshdir= workdir .. "/.ssh"
templateldir= workdir .. "/template"
fwcount_st="99"
fwcount_end="2000"
rsync_flags="arlHpEAXogt8 --delete"
greeting="node"
jailmapdb= dbdir .. "/jmap.txt"
-- external source for online doc
cbsddocsrc="http://www.bsdstore.ru/en" .. myversion .. "/"

f=io.open(nodenamefile,"r")
if f~=nil then 
    nodename = f:read("*l")
    io.close(f)
end

-- if [ -n "${NOCOLOR}" ]; then
--    ECHO="echo"
-- else
--    ECHO="echo -e"
--    [ -f "${color}" ] && . $color
-- fi

==> cbsd-11.0.4_1.txz: usr/local/cbsd/cbsd.lua <==
product="CBSD"
myversion="11.0.4"

if not workdir then
	print ( "no workdir" )
	os.exit(1)
end

distdir="/usr/local/cbsd"
subr= workdir .. "/nc.lua"
nodenamefile= workdir .. "/nodename"
settingstui= workdir .. "/settings-tui.subr"
dialog= workdir .. "/dialog.subr"
tools= workdir .. "/tools.subr"
mdtools= workdir .. "/mdtools.subr"
zfstool= workdir .. "/zfs.subr"
jfs= workdir .. "/jfs.subr"
color= workdir .. "/ansiicolor.subr"
nodes= workdir .. "/nodes.subr"
jrcconf= workdir .. "/rcconf.subr"
vimageconf= workdir .. "/vnet.subr"
vimagetui= workdir .. "/vnet-tui.subr"
inventory= workdir .. "/nc.inventory"
nodedescr= workdir .. "/node.desc"
initenv= workdir .. "/initenv.subr"
system= workdir .. "/system.subr"
buildconf= workdir .. "/build.subr"
distccacheconf= workdir .. "/distccache.subr"
base2pkgconf= workdir .. "/base2pkg.subr"
mailconf= workdir .. "/mailtools.subr"
strings= workdir .. "/strings.subr"
miscdir= workdir .. "/misc"
jobdir= workdir .. "/job"
srcdir= workdir .. "/src"
tmpdir= workdir .. "/tmp"
ftmpdir= workdir .. "/ftmp"
importdir= workdir .. "/import"
exportdir= workdir .. "/export"
basejaildir= workdir .. "/basejail"
basejailpref="base"
jaildatadir= workdir .. "/jails-data"
jailfstabdir= workdir .. "/jails-fstab"
jailrcconfdir= workdir .. "/jails-rcconf"
jailfstabpref="fstab."
jaildir= workdir .. "/jails"
jaildatapref="data"
jailsysdir= workdir .. "/jails-system"
bindir= workdir .. "/bin"
etcdir= workdir .. "/etc"
jailctldir= workdir .. "/jailctl"
nodectl= workdir .. "/nodectl"
rcddir= workdir .. "/rc.d"
sbindir= workdir .. "/sbin"
systemdir= workdir .. "/system"
moduledir= workdir .. "/modules"
toolsdir= workdir .. "/tools"
upgradedir= workdir .. "/upgrade"
vardir= workdir .. "/var"
spooldir= vardir .. "/spool"
taskdir= spooldir .. "/task"
rundir= vardir .. "/run"
maildir= vardir .. "/mail"
logdir= vardir .. "/log"
sharedir= workdir .. "/share"
dbdir= vardir .. "/db"
localcbsdconffile= "/cbsd.lua"
localcbsdconf= workdir .. localcbsdconffile
sudoexecdir= workdir .. "/sudoexec"
systemsudoexecdir= distdir .. "/sudoexec"
cbsduser="cbsd"
production="0"
rsshdir= workdir .. "/.rssh"
sshdir= workdir .. "/.ssh"
templateldir= workdir .. "/template"
fwcount_st="99"
fwcount_end="2000"
greeting="node"
jailmapdb= dbdir .. "/jmap.txt"
-- external source for online doc
docversion="10.3"
cbsddocsrc="https://www.bsdstore.ru/en" .. docversion .. "/"

f=io.open(nodenamefile,"r")
if f ~= nil then
	nodename = f:read("*l")
	io.close(f)
end

-- if [ -n "${NOCOLOR}" ]; then
--    ECHO="echo"
-- else
--    ECHO="echo -e"
--    [ -f "${color}" ] && . $color
-- fi
